@@ -24,6 +24,7 @@
 package ch.kuramo.javie.app.actions;
 
 import org.eclipse.jface.action.Action;
+import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchWindow;
 
 import ch.kuramo.javie.app.CommandIds;
@@ -71,6 +72,7 @@ public class NewProjectAction extends Action {
 		ProjectManager pm = ProjectManager.newProject(window);
 
 		UIUtil.showView(window.getActivePage(), ProjectView.ID);
+		UIUtil.showView(window.getActivePage(), "org.eclipse.ui.console.ConsoleView", null, IWorkbenchPage.VIEW_CREATE);
 		return pm;
 	}
 
