@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -77,7 +77,7 @@ public class RemoveLayersOperation extends ProjectOperation {
 
 
 	public RemoveLayersOperation(ProjectManager pm, Collection<Layer> layers) {
-		super(pm, "レイヤーの消去");
+		super(pm, "レイヤーの削除");
 		InjectorHolder.getInjector().injectMembers(this);
 
 		LayerComposition comp = pm.checkLayer(layers.iterator().next());
