@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,10 +23,10 @@
 
 package ch.kuramo.javie.core;
 
-import ch.kuramo.javie.api.plugin.PIAudioBuffer;
+import ch.kuramo.javie.api.IAudioBuffer;
 
 public interface AudioEffect extends Effect {
 
-	PIAudioBuffer doAudioEffect();
+	IAudioBuffer doAudioEffect();
 
 }
