@@ -24,6 +24,10 @@
 package ch.kuramo.javie.core.internal.services;
 
 import ch.kuramo.javie.core.services.FontManager;
+
+import com.google.inject.Inject;
+import com.google.inject.Injector;
+
 import ftgl.FTGLfont;
 
 public class FontManagerProxy implements FontManager {
@@ -31,22 +35,33 @@ public class FontManagerProxy implements FontManager {
 	private static final ThreadLocal<FontManagerImpl>
 			_threadLocal = new ThreadLocal<FontManagerImpl>();
 
-	static FontManagerImpl createImpl() {
-		if (_threadLocal.get() != null) {
-			throw new IllegalStateException("FontManagerImpl already exists on this thread.");
+
+	static class Lifecycle {
+
+		private final Injector _injector;
+
+		@Inject
+		Lifecycle(Injector injector) {
+			_injector = injector;
+		}
+
+		void createImpl() {
+			if (_threadLocal.get() != null) {
+				throw new IllegalStateException("FontManagerImpl already exists on this thread.");
+			}
+			FontManagerImpl impl = _injector.getInstance(FontManagerImpl.class);
+			_threadLocal.set(impl);
+		}
+
+		void disposeImpl() {
+			FontManagerImpl impl = _threadLocal.get();
+			if (impl != null) {
+				impl.dispose();
+				_threadLocal.set(null);
+			}
 		}
-		FontManagerImpl impl = new FontManagerImpl();
-		_threadLocal.set(impl);
-		return impl;
 	}
 
-	static void disposeImpl() {
-		FontManagerImpl impl = _threadLocal.get();
-		if (impl != null) {
-			impl.dispose();
-			_threadLocal.set(null);
-		}
-	}
 
 	private FontManagerImpl getImpl() {
 		FontManagerImpl impl = _threadLocal.get();
