@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -44,6 +44,9 @@ import ch.kuramo.javie.core.MediaItemLayer;
 import ch.kuramo.javie.core.NullLayer;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.SolidColorItem;
+import ch.kuramo.javie.core.TARangeSelector;
+import ch.kuramo.javie.core.TAWigglySelector;
+import ch.kuramo.javie.core.TextAnimator;
 import ch.kuramo.javie.core.TextLayer;
 
 public interface ProjectElementFactory {
@@ -78,4 +81,10 @@ public interface ProjectElementFactory {
 
 	TextLayer newTextLayer();
 
+	TextAnimator newTextAnimator();
+
+	TARangeSelector newTARangeSelector();
+
+	TAWigglySelector newTAWigglySelector();
+
 }
